@@ -25,11 +25,11 @@ Template::Flute - Modern designer-friendly HTML templating Engine
 
 =head1 VERSION
 
-Version 0.024
+Version 0.025
 
 =cut
 
-our $VERSION = '0.024';
+our $VERSION = '0.025';
 
 =head1 SYNOPSIS
 
@@ -1163,7 +1163,7 @@ sub _replace_record {
                         if (!defined($newtext)) {
                             $newtext = '';
                         }
-                        $newtext =~ s/$regexp/$string/;
+                        $newtext =~ s/$regexp/$string/g;
                         $elt->set_att($att, $newtext)
                     };
                 };
@@ -1178,7 +1178,7 @@ sub _replace_record {
                     if (!defined($newtext)) {
                         $newtext = '';
                     }
-                    $newtext =~ s/$regexp/$string/;
+                    $newtext =~ s/$regexp/$string/g;
                     $elt->set_text($newtext);
                 };
             }
@@ -1822,6 +1822,11 @@ Prepends the value to the text found in the HTML template.
 Insert HTML residing in value as subtree of the corresponding HTML element.
 HTML will be parsed with L<XML::Twig>. See L</INSERT HTML> for an example.
 
+=item keep
+
+Preserves the text inside of the HTML element if value is false
+in the Perl sense.
+
 =item toggle
 
 Only shows corresponding HTML element if value is set.
@@ -1943,6 +1948,9 @@ element content, yielding such output:
   </li>
  </ul>
 
+Note: All matches of the pattern are subject to replacement, starting
+with version 0.025.
+
 =back
 
 =head1 SIMPLE OPERATORS
